@@ -16,7 +16,7 @@ def get_config() -> ConfigReader:
     :return: 配置信息类
     """
     bootstrap = get_bootstrap()
-    config_file_name = str(bootstrap.read_config('profiles.config'))
+    config_file_name = str(bootstrap.read_config('profiles.config.name'))
     config_file_path = str(bootstrap.read_config('profiles.config.path'))
     config_file_type = config_file_name.split('.')[1]
     config_path_yaml = os.path.join(config_file_path)
